import 'package:flutter/material.dart';
import 'package:carousel_slider/carousel_slider.dart';

final List<String> imgList = [
  'https://i.ibb.co/RpfC6jm/unsplash-E-ZJ6moim-KE-1.png',
  'https://i.ibb.co/RpfC6jm/unsplash-E-ZJ6moim-KE-1.png',
];

final List<Widget> imageSliders = imgList
    .map(
      (item) => ClipRRect(
        child: Stack(
          children: <Widget>[
            Image.network(item, fit: BoxFit.cover),
          ],
        ),
      ),
    )
    .toList();

class CarouselChallenge extends StatefulWidget {
  const CarouselChallenge({Key? key}) : super(key: key);

  @override
  State<CarouselChallenge> createState() => _CarouselChallengeState();
}

class _CarouselChallengeState extends State<CarouselChallenge> {
  int _current = 0;

  final CarouselController _controller = CarouselController();

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
          child: CarouselSlider(
            items: imageSliders,
            carouselController: _controller,
            options: CarouselOptions(
                height: 150,
                autoPlay: true,
                viewportFraction: 1.0,
                autoPlayInterval: const Duration(milliseconds: 5000),
                autoPlayAnimationDuration: const Duration(milliseconds: 1000),
                onPageChanged: (index, reason) {
                  setState(() {
                    _current = index;
                  });
                }),
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 105.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: imgList.asMap().entries.map(
              (entry) {
                return GestureDetector(
                  onTap: () => _controller.animateToPage(entry.key),
                  child: Container(
                    width: 9.0,
                    height: 9.0,
                    margin: const EdgeInsets.symmetric(
                        vertical: 8.0, horizontal: 4.0),
                    decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: (Theme.of(context).brightness == Brightness.dark
                                ? Colors.white.withOpacity(0.5)
                                : Colors.white)
                            .withOpacity(_current == entry.key ? 0.9 : 0.4)),
                  ),
                );
              },
            ).toList(),
          ),
        ),
      ],
    );
  }
}
