import 'package:flutter/material.dart';
import 'package:carousel_slider/carousel_slider.dart';
import 'package:flutter_svg/svg.dart';
import 'package:recup_app_storybook/theme/colors.dart';

final List<String> imgList = [
  'https://i.ibb.co/RpfC6jm/unsplash-E-ZJ6moim-KE-1.png',
  'https://i.ibb.co/RpfC6jm/unsplash-E-ZJ6moim-KE-1.png',
  'https://i.ibb.co/RpfC6jm/unsplash-E-ZJ6moim-KE-1.png',
];

final List<Widget> imageSliders = imgList
    .map(
      (item) => ClipRRect(
        child: Stack(
          children: <Widget>[
            Container(
              height: 200,
              decoration: const BoxDecoration(
                image: DecorationImage(
                  fit: BoxFit.fill,
                  image: AssetImage("assets/fundo2.png"),
                ),
              ),
              child: Padding(
                padding: const EdgeInsets.only(left: 18.0, right: 8.0, top: 22),
                child: Align(
                  alignment: Alignment.topCenter,
                  child: Row(
                    children: [
                      SvgPicture.asset("assets/icons/green/like2.svg",
                          height: 22, width: 22),
                      const SizedBox(width: 15),
                      SvgPicture.asset("assets/icons/green/challenges2.svg",
                          height: 22, width: 22),
                    ],
                  ),
                ),
              ),
            ),
          ],
        ),
      ),
    )
    .toList();

class RewardCarousel extends StatefulWidget {
  const RewardCarousel({Key? key}) : super(key: key);

  @override
  State<RewardCarousel> createState() => _RewardCarouselState();
}

class _RewardCarouselState extends State<RewardCarousel> {
  int _current = 0;

  final CarouselController _controller = CarouselController();

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Container(
          child: CarouselSlider(
            items: imageSliders,
            carouselController: _controller,
            options: CarouselOptions(
                height: 200,
                autoPlay: true,
                viewportFraction: 1.0,
                autoPlayInterval: const Duration(milliseconds: 5000),
                autoPlayAnimationDuration: const Duration(milliseconds: 1000),
                onPageChanged: (index, reason) {
                  setState(() {
                    _current = index;
                  });
                }),
          ),
        ),
        Padding(
          padding: const EdgeInsets.only(top: 165.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: imgList.asMap().entries.map(
              (entry) {
                return GestureDetector(
                  onTap: () => _controller.animateToPage(entry.key),
                  child: Container(
                    width: 9.0,
                    height: 9.0,
                    margin: const EdgeInsets.symmetric(
                        vertical: 8.0, horizontal: 4.0),
                    decoration: BoxDecoration(
                        shape: BoxShape.circle,
                        color: (Theme.of(context).brightness == Brightness.dark
                                ? color1.withOpacity(0.5)
                                : color1)
                            .withOpacity(_current == entry.key ? 0.9 : 0.4)),
                  ),
                );
              },
            ).toList(),
          ),
        ),
      ],
    );
  }
}
